@@ -16,12 +16,12 @@ from singer import utils
 import datetime
 import dateutil
 from dateutil import parser
+import pendulum
 
 
 REQUIRED_CONFIG_KEYS = ["url", "consumer_key", "consumer_secret", "start_date"]
 REQUEST_USER_AGENT = 'VELOCITY'
 LOGGER = singer.get_logger()
-
 CONFIG = {
     "url": None,
     "consumer_key": None,
@@ -47,8 +47,8 @@ def get_endpoint(endpoint, kwargs):
 def get_start(STATE, tap_stream_id, bookmark_key):
     current_bookmark = singer.get_bookmark(STATE, tap_stream_id, bookmark_key)
     if current_bookmark is None:
-        return parser.parse(CONFIG["start_date"]).isoformat()
-    return parser.parse(current_bookmark).isoformat()
+        return pendulum.parse(CONFIG["start_date"]).strftime('%Y-%m-%dT%H:%M:%SZ')
+    return pendulum.parse(current_bookmark).strftime('%Y-%m-%dT%H:%M:%SZ')
 
 def load_schema(entity):
     '''Returns the schema for the specified source'''
@@ -98,23 +98,26 @@ def filter_order(order):
         coupon_lines = [filter_coupons(coupon) for coupon in order["coupon_lines"]]
     else:
         coupon_lines = None
-    if "shippng_lines" in order and len(order["shipping_lines"])>0:
+    if "shipping_lines" in order and len(order["shipping_lines"])>0:
         shipping_lines = [filter_shipping(ship) for ship in order["shipping_lines"]]
     else:
         shipping_lines = None
 
-    filtered = {
-        "store_url": CONFIG["url"],
-        "order_id":int(order["id"]),
-        "order_key":str(order["order_key"]),
-        "status":str(order["status"]),
-        "date_created":parser.parse(order["date_created"]).replace(tzinfo=tzinfo).isoformat(),
-        "date_modified":parser.parse(order["date_modified"]).replace(tzinfo=tzinfo).isoformat(),
-        "discount_total":float(order["discount_total"]),
-        "shipping_total":float(order["shipping_total"]),
-        "total":float(order["total"]),
-        "line_items":line_items
-    }
+    try:
+        filtered = {
+            "store_url": CONFIG["url"],
+            "order_id":int(order["id"]),
+            "order_key":str(order["order_key"]),
+            "status":str(order["status"]),
+            "date_created":parser.parse(order["date_created"]).replace(tzinfo=tzinfo).isoformat(),
+            "date_modified":parser.parse(order["date_modified"]).replace(tzinfo=tzinfo).isoformat(),
+            "discount_total":float(order["discount_total"]),
+            "shipping_total":float(order["shipping_total"]),
+            "total":float(order["total"]),
+            "line_items":line_items
+        }
+    except:
+        filtered = {}    
     return filtered
 
 def giveup(exc):
